translate.tools.poterminology

Package translate :: Package tools :: Module poterminology |
[hide private]
[frames] | no frames]

# Module poterminology

source code

reads a set of .po or .pot files to produce a pootle-terminology.pot

See: http://translate.sourceforge.net/wiki/toolkit/poterminology for examples and usage instructions

Classes | [hide private]
| TerminologyExtractor
| TerminologyOptionParser a specialized Option Parser for the terminology tool...

Functions | [hide private]
create_termunit(term, unit, targets, locations, sourcenotes, transnotes, filecounts) | source code
fold_case_option(option, opt_str, value, parser) | source code
preserve_case_option(option, opt_str, value, parser) | source code
main() | source code

Imports: os, re, sys, logging, lang_factory, optrecurse, po, factory, file_discovery